# Instalação

Faça a instalação do `cbers4asat` com o pip:

```
pip install cbers4asat
```

Instalação com a caixa de ferramentas:

```
pip install "cbers4asat[tools]"
```

## Versões do Python suportadas

Atualmente a biblioteca possui suporte confirmado para versões maiores ou igual a `3.11`.

[Linux] Para verificar a versão do python instalada na sua máquina, abra um terminal e digite o comando:

```commandline
python3 --version
```
